hesseflux.functions.opti_test_functions
=======================================

.. automodule:: hesseflux.functions.opti_test_functions
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:

.. raw:: latex

    \clearpage
